@@ -29,6 +29,7 @@ from .core import (
     to_yaml,
     unsafe_merge,
 )
+from .flexyclasses import is_flexyclass
 from .logging import configure_logging
 from .nicknames import NicknameRegistry
 from .rich_utils import (
@@ -260,8 +261,17 @@ def load_from_file_or_nickname(
         loaded_config = NicknameRegistry.get(
             name=config_path_or_nickname, raise_if_missing=True
         )
-        if not isinstance(loaded_config, (DictConfig, ListConfig)):
+
+        if is_dataclass(loaded_config):
             loaded_config = from_dataclass(loaded_config)
+        elif is_flexyclass(loaded_config):
+            loaded_config = loaded_config.to_dict_config()  # type: ignore
+        elif not isinstance(loaded_config, (DictConfig, ListConfig)):
+            raise ValueError(
+                f"Nickname '{config_path_or_nickname}' is not a "
+                "DictConfig or ListConfig."
+            )
+
     else:
         # config file is to load from file
         loaded_config = from_file(config_path_or_nickname)
@@ -335,7 +345,12 @@ def wrap_main_method(
 
     # Print default options if requested py the user
     if opts.options:
-        print_config_as_tree(title="Default Options", config=config_node)
+        print_config_as_tree(
+            title="Default Options",
+            config=config_node,
+            title_color="green",
+            print_help=True,
+        )
 
     # This configuration is used to accumulate all options across
     # various config files and the CLI.
@@ -350,9 +365,10 @@ def wrap_main_method(
         # print the configuration if requested by the user
         if opts.inputs:
             print_config_as_tree(
-                title=f"Input From File {file_config}",
+                title=f"Input From File {config_file}",
                 config=file_config,
-                title_color="blue",
+                title_color="green",
+                print_help=False,
             )
 
         # merge the file config with the main config
@@ -366,7 +382,8 @@ def wrap_main_method(
         print_config_as_tree(
             title="Input From Command Line",
             config=cli_config,
-            title_color="red",
+            title_color="green",
+            print_help=False,
         )
 
     # merge the cli config with the main config, do it last
@@ -389,6 +406,7 @@ def wrap_main_method(
             title="Parsed Config",
             config=parsed_config,
             title_color="green",
+            print_help=False,
         )
 
     if opts.save is not None:
